# Meta-analyses on p-values of differential analyses

|Build|Status|
|-----|----|
| [Bioc-release](https://bioconductor.org/packages/release/bioc/html/metapod.html) | [![](https://bioconductor.org/shields/build/release/bioc/metapod.svg)](https://bioconductor.org/checkResults/release/bioc-LATEST/metapod) |
| [Bioc-devel](https://bioconductor.org/packages/devel/bioc/html/metapod.html) | [![](https://bioconductor.org/shields/build/devel/bioc/metapod.svg)](https://bioconductor.org/checkResults/devel/bioc-LATEST/metapod) | 

This package implements a variety of methods for combining p-values in differential analyses of genome-scale datasets.
It was initially designed for meta-analysis of differentially binding statistics in ChIP-seq,
but can be applied to any situation with many grouped or parallel sets of p-values.
Check out the user's guide on the [Bioconductor landing page](https://bioconductor.org/packages/devel/bioc/html/metapod.html) for more details.
