# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

compute_grouped_simes <- function(pvals, runs, weights, log) {
    .Call('_metapod_compute_grouped_simes', PACKAGE = 'metapod', pvals, runs, weights, log)
}

compute_grouped_berger <- function(pvals, runs, weights, log) {
    .Call('_metapod_compute_grouped_berger', PACKAGE = 'metapod', pvals, runs, weights, log)
}

compute_grouped_wilkinson <- function(pvals, runs, weights, log, min_n, min_prop) {
    .Call('_metapod_compute_grouped_wilkinson', PACKAGE = 'metapod', pvals, runs, weights, log, min_n, min_prop)
}

compute_grouped_holm_min <- function(pvals, runs, weights, log, min_n, min_prop) {
    .Call('_metapod_compute_grouped_holm_min', PACKAGE = 'metapod', pvals, runs, weights, log, min_n, min_prop)
}

compute_grouped_stouffer <- function(pvals, runs, weights, log) {
    .Call('_metapod_compute_grouped_stouffer', PACKAGE = 'metapod', pvals, runs, weights, log)
}

compute_grouped_fisher <- function(pvals, runs, weights, log) {
    .Call('_metapod_compute_grouped_fisher', PACKAGE = 'metapod', pvals, runs, weights, log)
}

compute_grouped_pearson <- function(pvals, runs, weights, log) {
    .Call('_metapod_compute_grouped_pearson', PACKAGE = 'metapod', pvals, runs, weights, log)
}

compute_parallel_simes <- function(pvals, weights, log) {
    .Call('_metapod_compute_parallel_simes', PACKAGE = 'metapod', pvals, weights, log)
}

compute_parallel_berger <- function(pvals, weights, log) {
    .Call('_metapod_compute_parallel_berger', PACKAGE = 'metapod', pvals, weights, log)
}

compute_parallel_wilkinson <- function(pvals, weights, log, min_n, min_prop) {
    .Call('_metapod_compute_parallel_wilkinson', PACKAGE = 'metapod', pvals, weights, log, min_n, min_prop)
}

compute_parallel_holm_min <- function(pvals, weights, log, min_n, min_prop) {
    .Call('_metapod_compute_parallel_holm_min', PACKAGE = 'metapod', pvals, weights, log, min_n, min_prop)
}

compute_parallel_stouffer <- function(pvals, weights, log) {
    .Call('_metapod_compute_parallel_stouffer', PACKAGE = 'metapod', pvals, weights, log)
}

compute_parallel_fisher <- function(pvals, weights, log) {
    .Call('_metapod_compute_parallel_fisher', PACKAGE = 'metapod', pvals, weights, log)
}

compute_parallel_pearson <- function(pvals, weights, log) {
    .Call('_metapod_compute_parallel_pearson', PACKAGE = 'metapod', pvals, weights, log)
}

count_parallel_direction <- function(pvalues, effects, method, pthreshold, ethreshold, log) {
    .Call('_metapod_count_parallel_direction', PACKAGE = 'metapod', pvalues, effects, method, pthreshold, ethreshold, log)
}

count_grouped_direction <- function(pvalues, runs, effects, method, pthreshold, ethreshold, log) {
    .Call('_metapod_count_grouped_direction', PACKAGE = 'metapod', pvalues, runs, effects, method, pthreshold, ethreshold, log)
}

summarize_parallel_direction <- function(effects, influential, threshold) {
    .Call('_metapod_summarize_parallel_direction', PACKAGE = 'metapod', effects, influential, threshold)
}

summarize_grouped_direction <- function(effects, runs, influential, threshold) {
    .Call('_metapod_summarize_grouped_direction', PACKAGE = 'metapod', effects, runs, influential, threshold)
}

